package nl.tue.astar.util;

import nl.tue.astar.Record;

public class BreadthFirstFastLookupPriorityQueue extends
		AbstractFastLookupPriorityQueue {

	/**
	 * Creates a {@code PriorityQueue} with the specified initial capacity that
	 * orders its elements according to the specified comparator.
	 * 
	 * @param initialCapacity
	 *            the initial capacity for this priority queue
	 * @param comparator
	 *            the comparator that will be used to order this priority queue.
	 *            If {@code null}, the {@linkplain Comparable natural ordering}
	 *            of the elements will be used.
	 * @throws IllegalArgumentException
	 *             if {@code initialCapacity} is less than 1
	 */

	public BreadthFirstFastLookupPriorityQueue(int initialCapacity) {
		super(initialCapacity);
	}

	@Override
	protected boolean isBetter(Record r1, Record r2) {
		// retrieve stored cost
		int c1 = r1.getTotalCost();
		int c2 = r2.getTotalCost();

		if (c1 < c2 || (c1 == c2 && r1.getCostSoFar() < r2.getCostSoFar())) {
			return true;
		}
		return false;
	}

}
